# Core FastAPI dependencies
fastapi>=0.100.0
uvicorn[standard]>=0.20.0
pydantic>=2.0.0
pydantic-settings>=2.0.0

# HTTP and middleware
httpx>=0.25.0
requests>=2.31.0
python-multipart>=0.0.6
python-jose[cryptography]>=3.3.0
passlib[bcrypt]>=1.7.4

# Database drivers and ORMs
sqlalchemy>=2.0.0
alembic>=1.10.0

# PostgreSQL
#psycopg2-binary>=2.9.9

# MySQL
#pymysql>=1.1.0

# MongoDB
#motor>=3.3.2
#pymongo>=4.6.0

# SQLite (included with Python)

# Redis
#redis>=5.0.1

# Celery
#celery>=5.3.4

# Background tasks
#celery[redis]>=5.3.4

# Environment variables
python-dotenv>=1.0.0

# Logging
structlog>=23.0.0
