# Test dependencies for {{ module_name }} module
pytest>=7.0.0
pytest-cov>=4.0.0
pytest-mock>=3.10.0
pytest-asyncio>=0.21.0
pytest-xdist>=3.0.0
pytest-html>=3.1.0
pytest-json-report>=1.5.0

# Performance testing
psutil>=5.9.0

# Database testing
sqlalchemy>=2.0.0
alembic>=1.10.0

# API testing
httpx>=0.24.0
fastapi>=0.100.0

# Mocking and utilities
factory-boy>=3.2.0
faker>=18.0.0
freezegun>=1.2.0
