# Production dependencies
# Install with: pip install -r requirements.prod.txt

# Core FastAPI dependencies
fastapi>=0.104.0
uvicorn[standard]>=0.24.0
pydantic>=2.5.0
pydantic-settings>=2.1.0

# HTTP and middleware
httpx>=0.25.0
python-multipart>=0.0.6
python-jose[cryptography]>=3.3.0
passlib[bcrypt]>=1.7.4

# Database drivers and ORMs
sqlalchemy>=2.0.23
alembic>=1.13.0

# PostgreSQL
psycopg2-binary>=2.9.9

# MySQL
pymysql>=1.1.0

# MongoDB
motor>=3.3.2
pymongo>=4.6.0

# Redis
redis>=5.0.1

# Celery
celery>=5.3.4

# CORS
python-cors>=1.7.0

# Environment variables
python-dotenv>=1.0.0

# Logging
structlog>=23.2.0

# Production server
gunicorn>=21.2.0

# Health checks
healthcheck>=1.3.0

# Monitoring
prometheus-client>=0.19.0

# Security
cryptography>=41.0.7

# Performance
orjson>=3.9.10
ujson>=5.8.0

# Caching
aioredis>=2.0.1

# Rate limiting
slowapi>=0.1.9

# Background tasks
celery[redis]>=5.3.4
