# Development dependencies
# Install with: pip install -r requirements.dev.txt

# Core development tools
-r requirements.txt

# Code quality and formatting
black>=23.11.0
isort>=5.12.0
flake8>=6.1.0
flake8-docstrings>=1.7.0
flake8-import-order>=0.18.2
flake8-quotes>=3.4.0

# Type checking
mypy>=1.7.1
types-requests>=2.31.0.10
types-PyYAML>=6.0.12.12

# Testing and coverage
pytest>=7.4.3
pytest-asyncio>=0.21.1
pytest-cov>=4.1.0
pytest-mock>=3.12.0
pytest-xdist>=3.5.0
coverage>=7.3.2

# Linting and security
bandit>=1.7.5
safety>=2.3.5

# Documentation
mkdocs>=1.5.3
mkdocs-material>=9.4.8
mkdocstrings[python]>=0.24.0

# Development server
watchdog>=3.0.0

# Database tools
pgcli>=4.0.1
mycli>=1.26.1

# API testing
httpie>=3.2.2
insomnia-rest-client>=0.1.0

# Monitoring and debugging
ipdb>=0.13.13
ipython>=8.17.2

# Pre-commit hooks
pre-commit>=3.5.0

# Jupyter for data exploration
jupyter>=1.0.0
notebook>=7.0.6
